(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0d7aa2"],{"787b":function(n,o,e){(function(n,e){e(o)})(0,(function(n){"use strict";var o="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["یک","دو","سه","چهار","پنج","جمعه","شنبه"],longhand:["یک‌شنبه","دوشنبه","سه‌شنبه","چهارشنبه","پنچ‌شنبه","جمعه","شنبه"]},months:{shorthand:["ژانویه","فوریه","مارس","آوریل","مه","ژوئن","ژوئیه","اوت","سپتامبر","اکتبر","نوامبر","دسامبر"],longhand:["ژانویه","فوریه","مارس","آوریل","مه","ژوئن","ژوئیه","اوت","سپتامبر","اکتبر","نوامبر","دسامبر"]},firstDayOfWeek:6,ordinal:function(){return""}};o.l10ns.fa=e;var a=o.l10ns;n.Persian=e,n.default=a,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0d7aa2.09d5d493.js.map