.square{display:inline-block;border-color:#ddd;border-radius:1px;margin-right:4px;height:11px;width:11px}.dropdown-submenu{position:relative}.dropdown-submenu .dropdown-menu{top:0;left:100%;margin-top:-1px}.background-darken[data-v-0e32cbfe]{background:rgba(0,0,0,.5);overflow-y:auto}