(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d210669"],{b874:function(e,n,r){(function(e,r){r(n)})(0,(function(e){"use strict";var n="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},r={weekdays:{shorthand:["Søn","Man","Tir","Ons","Tor","Fre","Lør"],longhand:["Søndag","Mandag","Tirsdag","Onsdag","Torsdag","Fredag","Lørdag"]},months:{shorthand:["Jan","Feb","Mar","Apr","Mai","Jun","Jul","Aug","Sep","Okt","Nov","Des"],longhand:["Januar","Februar","Mars","April","Mai","Juni","Juli","August","September","Oktober","November","Desember"]},firstDayOfWeek:1,rangeSeparator:" til ",weekAbbreviation:"Uke",scrollTitle:"Scroll for å endre",toggleTitle:"Klikk for å veksle",time_24hr:!0,ordinal:function(){return"."}};n.l10ns.no=r;var a=n.l10ns;e.Norwegian=r,e.default=a,Object.defineProperty(e,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d210669.cad6945b.js.map