(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b28e9"],{"252b":function(n,a,e){(function(n,e){e(a)})(0,(function(n){"use strict";var a="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},e={weekdays:{shorthand:["Sun","Mán","Þri","Mið","Fim","Fös","Lau"],longhand:["Sunnudagur","Mánudagur","Þriðjudagur","Miðvikudagur","Fimmtudagur","Föstudagur","Laugardagur"]},months:{shorthand:["Jan","Feb","Mar","Apr","Maí","Jún","Júl","Ágú","Sep","Okt","Nóv","Des"],longhand:["Janúar","Febrúar","Mars","Apríl","Maí","Júní","Júlí","Ágúst","September","Október","Nóvember","Desember"]},ordinal:function(){return"."},firstDayOfWeek:1,rangeSeparator:" til ",weekAbbreviation:"vika",yearAriaLabel:"Ár",time_24hr:!0};a.l10ns.is=e;var r=a.l10ns;n.Icelandic=e,n.default=r,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0b28e9.2c856757.js.map