(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e290e"],{"7ef0":function(n,e,a){(function(n,a){a(e)})(0,(function(n){"use strict";var e="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["Min","Isn","Sel","Rab","Kha","Jum","Sab"],longhand:["Minggu","Isnin","Selasa","Rabu","Khamis","Jumaat","Sabtu"]},months:{shorthand:["Jan","Feb","Mac","Apr","Mei","Jun","Jul","Ogo","Sep","Okt","Nov","Dis"],longhand:["Januari","Februari","Mac","April","Mei","Jun","Julai","Ogos","September","Oktober","November","Disember"]},firstDayOfWeek:1,ordinal:function(){return""}},i=e.l10ns;n.Malaysian=a,n.default=i,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0e290e.4e44099c.js.map