# Generated by Django 2.2.9 on 2020-02-20 17:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('modoboa_radicale', '0004_auto_20200220_1816'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sharedcalendar',
            name='access_token',
            field=models.CharField(max_length=50),
        ),
        migrations.AlterField(
            model_name='usercalendar',
            name='access_token',
            field=models.CharField(max_length=50),
        ),
    ]
