(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d22dd78"],{f8e5:function(n,o,d){(function(n,d){d(o)})(0,(function(n){"use strict";var o="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},d={weekdays:{shorthand:["أحد","اثنين","ثلاثاء","أربعاء","خميس","جمعة","سبت"],longhand:["الأحد","الاثنين","الثلاثاء","الأربعاء","الخميس","الجمعة","السبت"]},months:{shorthand:["1","2","3","4","5","6","7","8","9","10","11","12"],longhand:["يناير","فبراير","مارس","أبريل","مايو","يونيو","يوليو","أغسطس","سبتمبر","أكتوبر","نوفمبر","ديسمبر"]},rangeSeparator:" - "};o.l10ns.ar=d;var e=o.l10ns;n.Arabic=d,n.default=e,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d22dd78.f5799475.js.map