(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-7490c111"],{"60bcb":function(i,e,n){(function(i,n){n(e)})(0,(function(i){"use strict";var e="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={weekdays:{shorthand:["S","Pr","A","T","K","Pn","Š"],longhand:["Sekmadienis","Pirmadienis","Antradienis","Trečiadienis","Ketvirtadienis","Penktadienis","Šeštadienis"]},months:{shorthand:["Sau","Vas","Kov","Bal","Geg","Bir","Lie","Rgp","Rgs","Spl","Lap","Grd"],longhand:["Sausis","Vasaris","Kovas","Balandis","Gegužė","Birželis","Liepa","Rugpjūtis","Rugsėjis","Spalis","Lapkritis","Gruodis"]},firstDayOfWeek:1,ordinal:function(){return"-a"},weekAbbreviation:"Sav",scrollTitle:"Keisti laiką pelės rateliu",toggleTitle:"Perjungti laiko formatą",time_24hr:!0};e.l10ns.lt=n;var a=e.l10ns;i.Lithuanian=n,i.default=a,Object.defineProperty(i,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-7490c111.c0cd24f5.js.map