(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0dd3d3"],{8115:function(e,n,a){(function(e,a){a(n)})(0,(function(e){"use strict";var n="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["P","E","T","K","N","R","L"],longhand:["Pühapäev","Esmaspäev","Teisipäev","Kolmapäev","Neljapäev","Reede","Laupäev"]},months:{shorthand:["Jaan","Veebr","Märts","Apr","Mai","Juuni","Juuli","Aug","Sept","Okt","Nov","Dets"],longhand:["Jaanuar","Veebruar","Märts","Aprill","Mai","Juuni","Juuli","August","September","Oktoober","November","Detsember"]},firstDayOfWeek:1,ordinal:function(){return"."},weekAbbreviation:"Näd",rangeSeparator:" kuni ",scrollTitle:"Keri, et suurendada",toggleTitle:"Klõpsa, et vahetada",time_24hr:!0};n.l10ns.et=a;var t=n.l10ns;e.Estonian=a,e.default=t,Object.defineProperty(e,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0dd3d3.2156511e.js.map