(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d207328"],{a003:function(n,e,a){(function(n,a){a(e)})(0,(function(n){"use strict";var e="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},a={weekdays:{shorthand:["Нд","Пн","Аў","Ср","Чц","Пт","Сб"],longhand:["Нядзеля","Панядзелак","Аўторак","Серада","Чацвер","Пятніца","Субота"]},months:{shorthand:["Сту","Лют","Сак","Кра","Тра","Чэр","Ліп","Жні","Вер","Кас","Ліс","Сне"],longhand:["Студзень","Люты","Сакавік","Красавік","Травень","Чэрвень","Ліпень","Жнівень","Верасень","Кастрычнік","Лістапад","Снежань"]},firstDayOfWeek:1,ordinal:function(){return""},rangeSeparator:" — ",weekAbbreviation:"Тыд.",scrollTitle:"Пракруціце для павелічэння",toggleTitle:"Націсніце для пераключэння",amPM:["ДП","ПП"],yearAriaLabel:"Год",time_24hr:!0};e.l10ns.be=a;var o=e.l10ns;n.Belarusian=a,n.default=o,Object.defineProperty(n,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d207328.29ef0191.js.map