(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0cfac5"],{"655e":function(i,e,n){(function(i,n){n(e)})(0,(function(i){"use strict";var e="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},n={weekdays:{shorthand:["Dum","Lun","Mar","Mie","Joi","Vin","Sâm"],longhand:["Duminică","Luni","Marți","Miercuri","Joi","Vineri","Sâmbătă"]},months:{shorthand:["Ian","Feb","Mar","Apr","Mai","Iun","Iul","Aug","Sep","Oct","Noi","Dec"],longhand:["Ianuarie","Februarie","Martie","Aprilie","Mai","Iunie","Iulie","August","Septembrie","Octombrie","Noiembrie","Decembrie"]},firstDayOfWeek:1,time_24hr:!0,ordinal:function(){return""}};e.l10ns.ro=n;var r=e.l10ns;i.Romanian=n,i.default=r,Object.defineProperty(i,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0cfac5.6f313dad.js.map