(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0e5230"],{"92cd":function(e,n,o){(function(e,o){o(n)})(0,(function(e){"use strict";var n="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},o={weekdays:{shorthand:["Ned","Pon","Tor","Sre","Čet","Pet","Sob"],longhand:["Nedelja","Ponedeljek","Torek","Sreda","Četrtek","Petek","Sobota"]},months:{shorthand:["Jan","Feb","Mar","Apr","Maj","Jun","Jul","Avg","Sep","Okt","Nov","Dec"],longhand:["Januar","Februar","Marec","April","Maj","Junij","Julij","Avgust","September","Oktober","November","December"]},firstDayOfWeek:1,rangeSeparator:" do ",time_24hr:!0,ordinal:function(){return"."}};n.l10ns.sl=o;var r=n.l10ns;e.Slovenian=o,e.default=r,Object.defineProperty(e,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0e5230.d1d0ead1.js.map