(window["webpackJsonp"]=window["webpackJsonp"]||[]).push([["chunk-2d0b5fc8"],{"1adf":function(e,n,t){(function(e,t){t(n)})(0,(function(e){"use strict";var n="undefined"!==typeof window&&void 0!==window.flatpickr?window.flatpickr:{l10ns:{}},t={weekdays:{shorthand:["So","Mo","Di","Mi","Do","Fr","Sa"],longhand:["Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag"]},months:{shorthand:["Jän","Feb","Mär","Apr","Mai","Jun","Jul","Aug","Sep","Okt","Nov","Dez"],longhand:["Jänner","Februar","März","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember"]},firstDayOfWeek:1,weekAbbreviation:"KW",rangeSeparator:" bis ",scrollTitle:"Zum Ändern scrollen",toggleTitle:"Zum Umschalten klicken"};n.l10ns.at=t;var o=n.l10ns;e.Austria=t,e.default=o,Object.defineProperty(e,"__esModule",{value:!0})}))}}]);
//# sourceMappingURL=chunk-2d0b5fc8.734e57f4.js.map